@@ -50,9 +50,6 @@ static void apply_fan_entry_token(char *token, char *value, void *data)
         pFanEntry->fan_speed = atoi(value);
     } else if (!strcasecmp("fail", token)) {
         pFanEntry->fan_failed = atoi(value);
-    } else {
-        nv_warning_msg("Unknown Fan Entry token value pair: %s=%s",
-                       token, value);
     }
 }
 
@@ -66,9 +63,6 @@ static void apply_thermal_entry_token(char *token, char *value, void *data)
         pThermalEntry->exhaust_temp = atoi(value);
     } else if (!strcasecmp("board", token)) {
         pThermalEntry->board_temp = atoi(value);
-    } else {
-        nv_warning_msg("Unknown Thermal Entry token value pair: %s=%s",
-                       token, value);
     }
 }
 
@@ -96,9 +90,6 @@ static void apply_psu_entry_token(char *token, char *value, void *data)
         } else {
             pPSUEntry->psu_state = VCS_PSU_STATE_ABNORMAL;
         }
-    } else {
-        nv_warning_msg("Unknown PSU Entry token value pair: %s=%s",
-                       token, value);
     }
 }
 
@@ -134,17 +125,18 @@ static gboolean update_vcs_info(gpointer user_data)
     char *temp_str = NULL;
     char *psu_str = NULL;
     CtkVcs *ctk_object = CTK_VCS(user_data);
+    CtrlTarget *ctrl_target = ctk_object->ctrl_target;
     ThermalEntry thermEntry;
-    PSUEntry psuEntry; 
+    PSUEntry psuEntry;
     gboolean high_perf_mode;
 
     /* These queries should always succeed for Canoas 2.0 and above */
-    if ((NvCtrlGetAttribute(ctk_object->handle, NV_CTRL_VCSC_HIGH_PERF_MODE, 
+    if ((NvCtrlGetAttribute(ctrl_target, NV_CTRL_VCSC_HIGH_PERF_MODE,
                             &high_perf_mode) != NvCtrlSuccess) ||
-        (NvCtrlGetStringAttribute(ctk_object->handle,
+        (NvCtrlGetStringAttribute(ctrl_target,
                                   NV_CTRL_STRING_VCSC_TEMPERATURES,
                                    &temp_str) != NvCtrlSuccess) ||
-        (NvCtrlGetStringAttribute(ctk_object->handle,
+        (NvCtrlGetStringAttribute(ctrl_target,
                                   NV_CTRL_STRING_VCSC_PSU_INFO,
                                   &psu_str) != NvCtrlSuccess)) {
             return FALSE;
@@ -250,12 +242,12 @@ static GtkWidget * create_error_dialog(CtkVcs *ctk_object)
 
     /* Main horizontal box */
     hbox = gtk_hbox_new(FALSE, 5);
-    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),
+    gtk_box_pack_start(GTK_BOX(ctk_dialog_get_content_area(GTK_DIALOG(dialog))),
                        hbox, TRUE, TRUE, 5);
 
     /* Pack the information icon */
-    image = gtk_image_new_from_stock(GTK_STOCK_DIALOG_INFO,
-                                     GTK_ICON_SIZE_DIALOG);
+    image = ctk_image_new_from_str(CTK_STOCK_DIALOG_INFO,
+                                   GTK_ICON_SIZE_DIALOG);
     gtk_misc_set_alignment(GTK_MISC(image), 0.0f, 0.0f);
     gtk_box_pack_start(GTK_BOX(hbox), image, FALSE, FALSE, 5);
     
@@ -273,7 +265,7 @@ static GtkWidget * create_error_dialog(CtkVcs *ctk_object)
     gtk_dialog_add_button(GTK_DIALOG(dialog), "OK",
                           GTK_RESPONSE_ACCEPT);
 
-    gtk_widget_show_all(GTK_DIALOG(dialog)->vbox);
+    gtk_widget_show_all(ctk_dialog_get_content_area(GTK_DIALOG(dialog)));
 
     return dialog;
 
@@ -283,12 +275,13 @@ static GtkWidget * create_error_dialog(CtkVcs *ctk_object)
 static void vcs_perf_checkbox_toggled(GtkWidget *widget, gpointer user_data)
 {
     CtkVcs *ctk_object = CTK_VCS(user_data);
+    CtrlTarget *ctrl_target = ctk_object->ctrl_target;
     gint enabled;
     gint ret;
 
     enabled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
 
-    ret = NvCtrlSetAttribute(ctk_object->handle, NV_CTRL_VCSC_HIGH_PERF_MODE, enabled);
+    ret = NvCtrlSetAttribute(ctrl_target, NV_CTRL_VCSC_HIGH_PERF_MODE, enabled);
 
     if (ret != NvCtrlSuccess) {
         if (ctk_object->error_dialog_label) {
@@ -322,6 +315,7 @@ static void vcs_perf_checkbox_toggled(GtkWidget *widget, gpointer user_data)
 
 static gboolean update_fan_status(CtkVcs *ctk_object)
 {
+    CtrlTarget *ctrl_target = ctk_object->ctrl_target;
     gint ret;
     char *fan_entry_str = NULL;
     char *tokens;
@@ -334,7 +328,7 @@ static gboolean update_fan_status(CtkVcs *ctk_object)
     if (!ctk_object->fan_status_container) {
         return FALSE;
     }
-    ret = NvCtrlGetStringAttribute(ctk_object->handle,
+    ret = NvCtrlGetStringAttribute(ctrl_target,
                                    NV_CTRL_STRING_VCSC_FAN_STATUS,
                                    &fan_entry_str);
     if (ret != NvCtrlSuccess) {
@@ -425,7 +419,7 @@ static gboolean update_fan_status(CtkVcs *ctk_object)
         }
     }
     gtk_widget_show_all(table);
-    XFree(fan_entry_str);
+    free(fan_entry_str);
     return TRUE;
 }
 
@@ -434,8 +428,8 @@ static gboolean update_fan_status(CtkVcs *ctk_object)
  * CTK VCS (Visual Computing System) widget creation
  *
  */
-GtkWidget* ctk_vcs_new(NvCtrlAttributeHandle *handle,
-                        CtkConfig *ctk_config)
+GtkWidget* ctk_vcs_new(CtrlTarget *ctrl_target,
+                       CtkConfig *ctk_config)
 {
     GObject *object;
     CtkVcs *ctk_object;
@@ -471,7 +465,7 @@ GtkWidget* ctk_vcs_new(NvCtrlAttributeHandle *handle,
      */
     
     /* Product Name */
-    ret = NvCtrlGetStringAttribute(handle,
+    ret = NvCtrlGetStringAttribute(ctrl_target,
                                    NV_CTRL_STRING_VCSC_PRODUCT_NAME,
                                    &product_name);
     if (ret != NvCtrlSuccess) {
@@ -479,7 +473,7 @@ GtkWidget* ctk_vcs_new(NvCtrlAttributeHandle *handle,
     }
 
     /* Serial Number */
-    ret = NvCtrlGetStringAttribute(handle,
+    ret = NvCtrlGetStringAttribute(ctrl_target,
                                    NV_CTRL_STRING_VCSC_SERIAL_NUMBER,
                                    &serial_number);
     if (ret != NvCtrlSuccess) {
@@ -487,7 +481,7 @@ GtkWidget* ctk_vcs_new(NvCtrlAttributeHandle *handle,
     }
 
     /* Build Date */
-    ret = NvCtrlGetStringAttribute(handle,
+    ret = NvCtrlGetStringAttribute(ctrl_target,
                                    NV_CTRL_STRING_VCSC_BUILD_DATE,
                                    &build_date);
     if (ret != NvCtrlSuccess) {
@@ -495,7 +489,7 @@ GtkWidget* ctk_vcs_new(NvCtrlAttributeHandle *handle,
     }
 
     /* Product ID */
-    ret = NvCtrlGetStringAttribute(handle,
+    ret = NvCtrlGetStringAttribute(ctrl_target,
                                    NV_CTRL_STRING_VCSC_PRODUCT_ID,
                                    &product_id);
     if (ret != NvCtrlSuccess) {
@@ -503,7 +497,7 @@ GtkWidget* ctk_vcs_new(NvCtrlAttributeHandle *handle,
     }
 
     /* Firmware Version */
-    ret = NvCtrlGetStringAttribute(handle,
+    ret = NvCtrlGetStringAttribute(ctrl_target,
                                    NV_CTRL_STRING_VCSC_FIRMWARE_VERSION,
                                    &firmware_version);
     if (ret != NvCtrlSuccess) {
@@ -511,7 +505,7 @@ GtkWidget* ctk_vcs_new(NvCtrlAttributeHandle *handle,
     }
 
     /* Hardware Version */
-    ret = NvCtrlGetStringAttribute(handle,
+    ret = NvCtrlGetStringAttribute(ctrl_target,
                                    NV_CTRL_STRING_VCSC_HARDWARE_VERSION,
                                    &hardware_version);
     if (ret != NvCtrlSuccess) {
@@ -520,13 +514,13 @@ GtkWidget* ctk_vcs_new(NvCtrlAttributeHandle *handle,
 
 
     /* now, create the object */
-    
+
     object = g_object_new(CTK_TYPE_VCS, NULL);
     ctk_object = CTK_VCS(object);
 
-    /* cache the attribute handle */
+    /* cache the target */
 
-    ctk_object->handle = handle;
+    ctk_object->ctrl_target = ctrl_target;
     ctk_object->ctk_config = ctk_config;
 
     /* set container properties of the object */
@@ -549,7 +543,7 @@ GtkWidget* ctk_vcs_new(NvCtrlAttributeHandle *handle,
     /* General purpose error dialog */
     ctk_object->error_dialog = create_error_dialog(ctk_object);
 
-    if (NvCtrlGetAttribute(ctk_object->handle, NV_CTRL_VCSC_HIGH_PERF_MODE,
+    if (NvCtrlGetAttribute(ctrl_target, NV_CTRL_VCSC_HIGH_PERF_MODE,
                             &high_perf_mode) == NvCtrlSuccess) {
 
         hbox = gtk_hbox_new(FALSE, 0);
@@ -567,10 +561,9 @@ GtkWidget* ctk_vcs_new(NvCtrlAttributeHandle *handle,
     hbox_scroll = gtk_hbox_new(FALSE, 0);
     vbox_scroll = gtk_vbox_new(FALSE, 5);
     event = gtk_event_box_new();
+    ctk_force_text_colors_on_widget(event);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrollWin),
                                    GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
-    gtk_widget_modify_fg(event, GTK_STATE_NORMAL, &(event->style->text[GTK_STATE_NORMAL]));
-    gtk_widget_modify_bg(event, GTK_STATE_NORMAL, &(event->style->base[GTK_STATE_NORMAL]));
     gtk_container_add(GTK_CONTAINER(event), hbox_scroll);
     gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrollWin),
                                           event);
@@ -617,9 +610,9 @@ GtkWidget* ctk_vcs_new(NvCtrlAttributeHandle *handle,
 
 
     /* Query Canoas 2.0 specific details */
-    if ((NvCtrlGetAttribute(ctk_object->handle, NV_CTRL_VCSC_HIGH_PERF_MODE, 
-                            &high_perf_mode) == NvCtrlSuccess) && 
-        (NvCtrlGetStringAttribute(ctk_object->handle,
+    if ((NvCtrlGetAttribute(ctrl_target, NV_CTRL_VCSC_HIGH_PERF_MODE,
+                            &high_perf_mode) == NvCtrlSuccess) &&
+        (NvCtrlGetStringAttribute(ctrl_target,
                                   NV_CTRL_STRING_VCSC_PSU_INFO,
                                   &psu_str)  == NvCtrlSuccess)) {
         GtkWidget *vbox_padding;
@@ -658,7 +651,7 @@ GtkWidget* ctk_vcs_new(NvCtrlAttributeHandle *handle,
 
         label = gtk_label_new("Exhaust Temperature:");
         /* This is the current largest label.  Get its size */
-        gtk_widget_size_request(label, &ctk_object->req);
+        ctk_widget_get_preferred_size(label, &ctk_object->req);
 
         gtk_misc_set_alignment(GTK_MISC(label), 0.0f, 0.5f);
         gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,
@@ -785,7 +778,7 @@ GtkWidget* ctk_vcs_new(NvCtrlAttributeHandle *handle,
 
         /* Register a timer callback to update the dynamic information */
         s = g_strdup_printf("VCS Monitor (VCS %d)",
-                            NvCtrlGetTargetId(ctk_object->handle));
+                            NvCtrlGetTargetId(ctrl_target));
 
         ctk_config_add_timer(ctk_object->ctk_config,
                              DEFAULT_UPDATE_VCS_INFO_TIME_INTERVAL,
@@ -798,7 +791,7 @@ GtkWidget* ctk_vcs_new(NvCtrlAttributeHandle *handle,
     }
 
     gtk_widget_show_all(GTK_WIDGET(object));
-    
+
     return GTK_WIDGET(object);
 }
 
